@@ -1,9 +1,10 @@
 """CherryPy dispatchers.
 
 A 'dispatcher' is the object which looks up the 'page handler' callable
-and collects config for the current request based on the path_info, other
-request attributes, and the application architecture. The core calls the
-dispatcher as early as possible, passing it a 'path_info' argument.
+and collects config for the current request based on the path_info,
+other request attributes, and the application architecture. The core
+calls the dispatcher as early as possible, passing it a 'path_info'
+argument.
 
 The default dispatcher discovers the page handler by matching path_info
 to a hierarchical arrangement of objects, starting at request.app.root.
@@ -21,7 +22,6 @@ import cherrypy
 
 
 class PageHandler(object):
-
     """Callable which sets response.body."""
 
     def __init__(self, callable, *args, **kwargs):
@@ -29,32 +29,26 @@ class PageHandler(object):
         self.args = args
         self.kwargs = kwargs
 
-    def get_args(self):
+    @property
+    def args(self):
+        """The ordered args should be accessible from post dispatch hooks."""
         return cherrypy.serving.request.args
 
-    def set_args(self, args):
+    @args.setter
+    def args(self, args):
         cherrypy.serving.request.args = args
         return cherrypy.serving.request.args
 
-    args = property(
-        get_args,
-        set_args,
-        doc='The ordered args should be accessible from post dispatch hooks'
-    )
-
-    def get_kwargs(self):
+    @property
+    def kwargs(self):
+        """The named kwargs should be accessible from post dispatch hooks."""
         return cherrypy.serving.request.kwargs
 
-    def set_kwargs(self, kwargs):
+    @kwargs.setter
+    def kwargs(self, kwargs):
         cherrypy.serving.request.kwargs = kwargs
         return cherrypy.serving.request.kwargs
 
-    kwargs = property(
-        get_kwargs,
-        set_kwargs,
-        doc='The named kwargs should be accessible from post dispatch hooks'
-    )
-
     def __call__(self):
         try:
             return self.callable(*self.args, **self.kwargs)
@@ -64,14 +58,13 @@ class PageHandler(object):
                 test_callable_spec(self.callable, self.args, self.kwargs)
             except cherrypy.HTTPError:
                 raise sys.exc_info()[1]
-            except:
+            except Exception:
                 raise x
             raise
 
 
 def test_callable_spec(callable, callable_args, callable_kwargs):
-    """
-    Inspect callable and test to see if the given args are suitable for it.
+    """Inspect callable and test to see if the given args are suitable for it.
 
     When an error occurs during the handler's invoking stage there are 2
     erroneous cases:
@@ -209,13 +202,11 @@ def test_callable_spec(callable, callable_args, callable_kwargs):
 try:
     import inspect
 except ImportError:
-    test_callable_spec = lambda callable, args, kwargs: None
+    def test_callable_spec(callable, args, kwargs):  # noqa: F811
+        return None
 else:
-    getargspec = inspect.getargspec
-    # Python 3 requires using getfullargspec if keyword-only arguments are present
-    if hasattr(inspect, 'getfullargspec'):
-        def getargspec(callable):
-            return inspect.getfullargspec(callable)[:4]
+    def getargspec(callable):
+        return inspect.getfullargspec(callable)[:4]
 
 
 class LateParamPageHandler(PageHandler):
@@ -228,20 +219,19 @@ class LateParamPageHandler(PageHandler):
     (it's more complicated than that, but that's the effect).
     """
 
-    def _get_kwargs(self):
+    @property
+    def kwargs(self):
+        """Page handler kwargs (with cherrypy.request.params copied in)."""
         kwargs = cherrypy.serving.request.params.copy()
         if self._kwargs:
             kwargs.update(self._kwargs)
         return kwargs
 
-    def _set_kwargs(self, kwargs):
+    @kwargs.setter
+    def kwargs(self, kwargs):
         cherrypy.serving.request.kwargs = kwargs
         self._kwargs = kwargs
 
-    kwargs = property(_get_kwargs, _set_kwargs,
-                      doc='page handler kwargs (with '
-                      'cherrypy.request.params copied in)')
-
 
 if sys.version_info < (3, 0):
     punctuation_to_underscores = string.maketrans(
@@ -261,16 +251,16 @@ else:
 
 
 class Dispatcher(object):
-
     """CherryPy Dispatcher which walks a tree of objects to find a handler.
 
-    The tree is rooted at cherrypy.request.app.root, and each hierarchical
-    component in the path_info argument is matched to a corresponding nested
-    attribute of the root object. Matching handlers must have an 'exposed'
-    attribute which evaluates to True. The special method name "index"
-    matches a URI which ends in a slash ("/"). The special method name
-    "default" may match a portion of the path_info (but only when no longer
-    substring of the path_info matches some other object).
+    The tree is rooted at cherrypy.request.app.root, and each
+    hierarchical component in the path_info argument is matched to a
+    corresponding nested attribute of the root object. Matching handlers
+    must have an 'exposed' attribute which evaluates to True. The
+    special method name "index" matches a URI which ends in a slash
+    ("/"). The special method name "default" may match a portion of the
+    path_info (but only when no longer substring of the path_info
+    matches some other object).
 
     This is the default, built-in dispatcher for CherryPy.
     """
@@ -315,9 +305,9 @@ class Dispatcher(object):
 
         The second object returned will be a list of names which are
         'virtual path' components: parts of the URL which are dynamic,
-        and were not used when looking up the handler.
-        These virtual path components are passed to the handler as
-        positional arguments.
+        and were not used when looking up the handler. These virtual
+        path components are passed to the handler as positional
+        arguments.
         """
         request = cherrypy.serving.request
         app = request.app
@@ -368,8 +358,8 @@ class Dispatcher(object):
                 # No path segment was removed.  Raise an error.
                 raise cherrypy.CherryPyException(
                     'A vpath segment was added.  Custom dispatchers may only '
-                    + 'remove elements.  While trying to process '
-                    + '{0} in {1}'.format(name, fullpath)
+                    'remove elements.  While trying to process '
+                    '{0} in {1}'.format(name, fullpath)
                 )
             elif segleft == pre_len:
                 # Assume that the handler used the current path segment, but
@@ -457,13 +447,11 @@ class Dispatcher(object):
 
 
 class MethodDispatcher(Dispatcher):
-
     """Additional dispatch based on cherrypy.request.method.upper().
 
-    Methods named GET, POST, etc will be called on an exposed class.
-    The method names must be all caps; the appropriate Allow header
-    will be output showing all capitalized method names as allowable
-    HTTP verbs.
+    Methods named GET, POST, etc will be called on an exposed class. The
+    method names must be all caps; the appropriate Allow header will be
+    output showing all capitalized method names as allowable HTTP verbs.
 
     Note that the containing class must be exposed, not the methods.
     """
@@ -501,16 +489,14 @@ class MethodDispatcher(Dispatcher):
 
 
 class RoutesDispatcher(object):
-
     """A Routes based dispatcher for CherryPy."""
 
     def __init__(self, full_result=False, **mapper_options):
-        """
-        Routes dispatcher
+        """Routes dispatcher.
 
-        Set full_result to True if you wish the controller
-        and the action to be passed on to the page handler
-        parameters. By default they won't be.
+        Set full_result to True if you wish the controller and the
+        action to be passed on to the page handler parameters. By
+        default they won't be.
         """
         import routes
         self.full_result = full_result
@@ -626,8 +612,7 @@ def XMLRPCDispatcher(next_dispatcher=Dispatcher()):
 
 def VirtualHost(next_dispatcher=Dispatcher(), use_x_forwarded_host=True,
                 **domains):
-    """
-    Select a different handler based on the Host header.
+    """Select a different handler based on the Host header.
 
     This can be useful when running multiple sites within one CP server.
     It allows several domains to point to different parts of a single
