@@ -1,7 +1,4 @@
-import six
-
 import cherrypy
-from cherrypy._cpcompat import sorted
 from cherrypy.test import helper
 
 script_names = ['', '/foo', '/users/fred/blog', '/corp/blog']
@@ -80,7 +77,7 @@ def setup_server():
             self.name = name
 
         def __unicode__(self):
-            return six.text_type(self.name)
+            return str(self.name)
 
         def __str__(self):
             return str(self.name)
@@ -100,13 +97,11 @@ def setup_server():
     class UserContainerNode(object):
 
         def POST(self, name):
-            """
-            Allow the creation of a new Object
-            """
+            """Allow the creation of a new Object."""
             return 'POST %d' % make_user(name)
 
         def GET(self):
-            return six.text_type(sorted(user_lookup.keys()))
+            return str(sorted(user_lookup.keys()))
 
         def dynamic_dispatch(self, vpath):
             try:
@@ -128,15 +123,11 @@ def setup_server():
                 raise cherrypy.HTTPError(404)
 
         def GET(self, *args, **kwargs):
-            """
-            Return the appropriate representation of the instance.
-            """
-            return six.text_type(self.user)
+            """Return the appropriate representation of the instance."""
+            return str(self.user)
 
         def POST(self, name):
-            """
-            Update the fields of the user instance.
-            """
+            """Update the fields of the user instance."""
             self.user.name = name
             return 'POST %d' % self.user.id
 
@@ -154,9 +145,7 @@ def setup_server():
                 return 'PUT %d' % make_user(name, self.id)
 
         def DELETE(self):
-            """
-            Delete the user specified at the id.
-            """
+            """Delete the user specified at the id."""
             id = self.user.id
             del user_lookup[self.user.id]
             del self.user
@@ -202,7 +191,6 @@ def setup_server():
             return 'IndexOnly index'
 
     class DecoratedPopArgs:
-
         """Test _cp_dispatch with @cherrypy.popargs."""
 
         @cherrypy.expose
@@ -216,7 +204,6 @@ def setup_server():
         'a', 'b', handler=ABHandler())(DecoratedPopArgs)
 
     class NonDecoratedPopArgs:
-
         """Test _cp_dispatch = cherrypy.popargs()"""
 
         _cp_dispatch = cherrypy.popargs('a')
@@ -226,8 +213,7 @@ def setup_server():
             return 'index: ' + str(a)
 
     class ParameterizedHandler:
-
-        """Special handler created for each request"""
+        """Special handler created for each request."""
 
         def __init__(self, a):
             self.a = a
@@ -241,8 +227,7 @@ def setup_server():
             return self.a
 
     class ParameterizedPopArgs:
-
-        """Test cherrypy.popargs() with a function call handler"""
+        """Test cherrypy.popargs() with a function call handler."""
     ParameterizedPopArgs = cherrypy.popargs(
         'a', handler=ParameterizedHandler)(ParameterizedPopArgs)
 
