@@ -354,9 +354,6 @@ class ToolTests(helper.CPWebCase):
         self.assertInBody(expected_msg)
 
     def testCombinedTools(self):
-        # https://github.com/cherrypy/cherrypy/issues/1849
-        return self.skip()
-
         expectedResult = (ntou('Hello,world') +
                           europoundUnicode).encode('utf-8')
         zbuf = io.BytesIO()
@@ -463,9 +460,7 @@ class SessionAuthTest(unittest.TestCase):
 
 class TestHooks:
     def test_priorities(self):
-        """
-        Hooks should sort by priority order.
-        """
+        """Hooks should sort by priority order."""
         Hook = cherrypy._cprequest.Hook
         hooks = [
             Hook(None, priority=48),
